==> kubernetes-model-certificates-5.3.2-sources.jar: io/fabric8/kubernetes/api/model/certificates/v1beta1/CertificateSigningRequestFluentImpl.java <==
package io.fabric8.kubernetes.api.model.certificates.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class CertificateSigningRequestFluentImpl<A extends io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent<A> {

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpecBuilder spec;
    private io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusBuilder status;

    public CertificateSigningRequestFluentImpl() {
    }

    public CertificateSigningRequestFluentImpl(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(int[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(char[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(byte[] arg1,int arg2) {
        return (A)withApiVersion(new String(arg1, arg2));
    }

    public A withNewApiVersion(byte[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(char[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withApiVersion(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(int[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(char[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(byte[] arg1,int arg2) {
        return (A)withKind(new String(arg1, arg2));
    }

    public A withNewKind(byte[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(char[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withKind(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata) {
        _visitables.get("metadata").remove(this.metadata);
        if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.MetadataNested<A> withNewMetadata() {
        return new MetadataNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
        return new MetadataNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.MetadataNested<A> editMetadata() {
        return withNewMetadataLike(getMetadata());
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.MetadataNested<A> editOrNewMetadata() {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpec getSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpec buildSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpec spec) {
        _visitables.get("spec").remove(this.spec);
        if (spec!=null){ this.spec= new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec() {
        return this.spec != null;
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.SpecNested<A> withNewSpec() {
        return new SpecNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.SpecNested<A> withNewSpecLike(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpec item) {
        return new SpecNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.SpecNested<A> editSpec() {
        return withNewSpecLike(getSpec());
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.SpecNested<A> editOrNewSpec() {
        return withNewSpecLike(getSpec() != null ? getSpec(): new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpecBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpec item) {
        return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatus getStatus() {
        return this.status!=null?this.status.build():null;
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatus buildStatus() {
        return this.status!=null?this.status.build():null;
    }

    public A withStatus(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatus status) {
        _visitables.get("status").remove(this.status);
        if (status!=null){ this.status= new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus() {
        return this.status != null;
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.StatusNested<A> withNewStatus() {
        return new StatusNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.StatusNested<A> withNewStatusLike(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatus item) {
        return new StatusNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.StatusNested<A> editStatus() {
        return withNewStatusLike(getStatus());
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.StatusNested<A> editOrNewStatus() {
        return withNewStatusLike(getStatus() != null ? getStatus(): new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatus item) {
        return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        CertificateSigningRequestFluentImpl that = (CertificateSigningRequestFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
        if (status != null ? !status.equals(that.status) :that.status != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
    }

    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.MetadataNested<N>> implements io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ObjectMetaBuilder builder;

            MetadataNestedImpl(ObjectMeta item) {
                this.builder = new ObjectMetaBuilder(this, item);
                        
            }

            MetadataNestedImpl() {
                this.builder = new ObjectMetaBuilder(this);
                        
            }

            public N and() {
                return (N) CertificateSigningRequestFluentImpl.this.withMetadata(builder.build());
            }

            public N endMetadata() {
                return and();
            }
    }


    public class SpecNestedImpl<N> extends io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpecFluentImpl<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.SpecNested<N>> implements io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpecBuilder builder;

            SpecNestedImpl(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpec item) {
                this.builder = new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpecBuilder(this, item);
                        
            }

            SpecNestedImpl() {
                this.builder = new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpecBuilder(this);
                        
            }

            public N and() {
                return (N) CertificateSigningRequestFluentImpl.this.withSpec(builder.build());
            }

            public N endSpec() {
                return and();
            }
    }


    public class StatusNestedImpl<N> extends io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluentImpl<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.StatusNested<N>> implements io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusBuilder builder;

            StatusNestedImpl(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatus item) {
                this.builder = new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusBuilder(this, item);
                        
            }

            StatusNestedImpl() {
                this.builder = new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusBuilder(this);
                        
            }

            public N and() {
                return (N) CertificateSigningRequestFluentImpl.this.withStatus(builder.build());
            }

            public N endStatus() {
                return and();
            }
    }


}

==> kubernetes-model-certificates-5.4.0-sources.jar: io/fabric8/kubernetes/api/model/certificates/v1beta1/CertificateSigningRequestFluentImpl.java <==
package io.fabric8.kubernetes.api.model.certificates.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class CertificateSigningRequestFluentImpl<A extends io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent<A> {

    private java.lang.String apiVersion;
    private java.lang.String kind;
    private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
    private io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpecBuilder spec;
    private io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusBuilder status;

    public CertificateSigningRequestFluentImpl() {
    }

    public CertificateSigningRequestFluentImpl(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
    }

    public java.lang.String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(java.lang.String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public java.lang.Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withApiVersion instead.
     */
        public A withNewApiVersion(java.lang.String arg0) {
        return (A)withApiVersion(new String(arg0));
    }

    public java.lang.String getKind() {
        return this.kind;
    }

    public A withKind(java.lang.String kind) {
        this.kind=kind; return (A) this;
    }

    public java.lang.Boolean hasKind() {
        return this.kind != null;
    }

    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withKind instead.
     */
        public A withNewKind(java.lang.String arg0) {
        return (A)withKind(new String(arg0));
    }

    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildMetadata instead.
     * @return The buildable object.
     */
        public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
        _visitables.get("metadata").remove(this.metadata);
        if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public java.lang.Boolean hasMetadata() {
        return this.metadata != null;
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.MetadataNested<A> withNewMetadata() {
        return new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluentImpl.MetadataNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
        return new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluentImpl.MetadataNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.MetadataNested<A> editMetadata() {
        return withNewMetadataLike(getMetadata());
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.MetadataNested<A> editOrNewMetadata() {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildSpec instead.
     * @return The buildable object.
     */
        public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpec getSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpec buildSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpec spec) {
        _visitables.get("spec").remove(this.spec);
        if (spec!=null){ this.spec= new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public java.lang.Boolean hasSpec() {
        return this.spec != null;
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.SpecNested<A> withNewSpec() {
        return new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluentImpl.SpecNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.SpecNested<A> withNewSpecLike(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpec item) {
        return new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluentImpl.SpecNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.SpecNested<A> editSpec() {
        return withNewSpecLike(getSpec());
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.SpecNested<A> editOrNewSpec() {
        return withNewSpecLike(getSpec() != null ? getSpec(): new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpecBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpec item) {
        return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildStatus instead.
     * @return The buildable object.
     */
        public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatus getStatus() {
        return this.status!=null?this.status.build():null;
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatus buildStatus() {
        return this.status!=null?this.status.build():null;
    }

    public A withStatus(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatus status) {
        _visitables.get("status").remove(this.status);
        if (status!=null){ this.status= new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public java.lang.Boolean hasStatus() {
        return this.status != null;
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.StatusNested<A> withNewStatus() {
        return new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluentImpl.StatusNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.StatusNested<A> withNewStatusLike(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatus item) {
        return new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluentImpl.StatusNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.StatusNested<A> editStatus() {
        return withNewStatusLike(getStatus());
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.StatusNested<A> editOrNewStatus() {
        return withNewStatusLike(getStatus() != null ? getStatus(): new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatus item) {
        return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        CertificateSigningRequestFluentImpl that = (CertificateSigningRequestFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
        if (status != null ? !status.equals(that.status) :that.status != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
    }

    public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.MetadataNested<N>> implements io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;

            MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
                this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
                        
            }

            MetadataNestedImpl() {
                this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
                        
            }

            public N and() {
                return (N) CertificateSigningRequestFluentImpl.this.withMetadata(builder.build());
            }

            public N endMetadata() {
                return and();
            }
    }


    public class SpecNestedImpl<N> extends io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpecFluentImpl<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.SpecNested<N>> implements io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpecBuilder builder;

            SpecNestedImpl(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpec item) {
                this.builder = new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpecBuilder(this, item);
                        
            }

            SpecNestedImpl() {
                this.builder = new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestSpecBuilder(this);
                        
            }

            public N and() {
                return (N) CertificateSigningRequestFluentImpl.this.withSpec(builder.build());
            }

            public N endSpec() {
                return and();
            }
    }


    public class StatusNestedImpl<N> extends io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluentImpl<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.StatusNested<N>> implements io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusBuilder builder;

            StatusNestedImpl(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatus item) {
                this.builder = new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusBuilder(this, item);
                        
            }

            StatusNestedImpl() {
                this.builder = new io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusBuilder(this);
                        
            }

            public N and() {
                return (N) CertificateSigningRequestFluentImpl.this.withStatus(builder.build());
            }

            public N endStatus() {
                return and();
            }
    }


}
